@@ -62,11 +62,11 @@ RatioSDRMS <- function(exp, obs, dat_dim = NULL, memb_dim = 'member',
     stop("Parameter 'exp' and 'obs' must be a numeric array.")
   }
   if (is.null(dim(exp)) | is.null(dim(obs))) {
-    stop(paste0("Parameter 'exp' and 'obs' must be array with as least two ",
-                "dimensions memb_dim and time_dim."))
+    stop("Parameter 'exp' and 'obs' must be array with as least two ",
+         "dimensions memb_dim and time_dim.")
   }
-  if (any(is.null(names(dim(exp))))| any(nchar(names(dim(exp))) == 0) |
-      any(is.null(names(dim(obs))))| any(nchar(names(dim(obs))) == 0)) {
+  if (any(is.null(names(dim(exp)))) | any(nchar(names(dim(exp))) == 0) |
+      any(is.null(names(dim(obs)))) | any(nchar(names(dim(obs))) == 0)) {
     stop("Parameter 'exp' and 'obs' must have dimension names.")
   }
   ## dat_dim
@@ -112,8 +112,8 @@ RatioSDRMS <- function(exp, obs, dat_dim = NULL, memb_dim = 'member',
   name_exp <- name_exp[-which(name_exp == memb_dim)]
   name_obs <- name_obs[-which(name_obs == memb_dim)]
   if (!identical(dim(exp)[name_exp], dim(obs)[name_obs])) {
-    stop(paste0("Parameter 'exp' and 'obs' must have same length of ",
-                "all the dimensions except 'dat_dim' and 'memb_dim'."))
+    stop("Parameter 'exp' and 'obs' must have same length of ",
+         "all the dimensions except 'dat_dim' and 'memb_dim'.")
   }
   ## pval
   if (!is.logical(pval) | length(pval) > 1) {
@@ -171,7 +171,7 @@ RatioSDRMS <- function(exp, obs, dat_dim = NULL, memb_dim = 'member',
 
   dif <- exp - InsertDim(ens_exp, 2, dim(exp)[2]) # [nexp, member, sdate]
   std <- apply(dif, 1, sd, na.rm = TRUE) # [nexp]
-  enosd <- apply(Eno(dif, names(dim(exp))[3]), 1, sum, na.rm = TRUE)
+  enosd <- rowSums(Eno(dif, names(dim(exp))[3]), na.rm = TRUE)
   
   # Create empty arrays
   ratiosdrms <- array(dim = c(nexp = as.numeric(nexp), nobs = as.numeric(nobs)))  # [nexp, nobs]
@@ -182,7 +182,7 @@ RatioSDRMS <- function(exp, obs, dat_dim = NULL, memb_dim = 'member',
       dif <- ens_exp[jexp, ] - ens_obs[jobs, ]
       rms <- mean(dif^2, na.rm = TRUE)^0.5
       enorms <- Eno(dif)
-      ratiosdrms[jexp, jobs] <- std[jexp]/rms
+      ratiosdrms[jexp, jobs] <- std[jexp] / rms
 
       if (pval) {
         F <- (enosd[jexp] * std[jexp]^2 / (enosd[jexp] - 1)) / (enorms * rms^2 / (enorms - 1))
